Index: ui/latency/latency_info.h |
diff --git a/ui/latency/latency_info.h b/ui/latency/latency_info.h |
index 1fe89f7f30e6ea8f54d05d9c224dfa897db5570b..f34e09ac8ea47f67560820c47c1ed3e261576b0e 100644 |
--- a/ui/latency/latency_info.h |
+++ b/ui/latency/latency_info.h |
@@ -68,9 +68,9 @@ enum LatencyComponentType { |
INPUT_EVENT_LATENCY_FORWARD_SCROLL_UPDATE_TO_MAIN_COMPONENT, |
// Timestamp when the event's ack is received by the RWH. |
INPUT_EVENT_LATENCY_ACK_RWH_COMPONENT, |
// Frame number when a window snapshot was requested. The snapshot |
// is taken when the rendering results actually reach the screen. |
- WINDOW_SNAPSHOT_FRAME_NUMBER_COMPONENT, |
+ BROWSER_SNAPSHOT_FRAME_NUMBER_COMPONENT, |
// Timestamp when a tab is requested to be shown. |
TAB_SHOW_COMPONENT, |
// Timestamp when the frame is swapped in renderer. |
@@ -68,9 +68,9 @@ enum LatencyComponentType { |
// Timestamp when the event's ack is received by the RWH. |
INPUT_EVENT_LATENCY_ACK_RWH_COMPONENT, |
- // Frame number when a window snapshot was requested. The snapshot |
+ // Frame number when a browser snapshot was requested. The snapshot |
// is taken when the rendering results actually reach the screen. |